@@ -22,6 +22,7 @@
 #include <sys/wait.h>
 #include <X11/keysym.h>
 #include <string.h>
+#include <strings.h>
 #include <time.h>
 
 #include "ratpoison.h"
@@ -82,6 +83,9 @@ static user_command user_commands[] =
     {"startup_message",	cmd_startup_message, arg_STRING},
     {"link",		cmd_link,	arg_STRING},
     {"alias",		cmd_alias,	arg_STRING},
+    {"unalias",		cmd_unalias,	arg_STRING},
+    {"prevscreen",	cmd_prevscreen,	arg_VOID},
+    {"nextscreen",	cmd_nextscreen,	arg_VOID},
     /*@end (tag required for genrpbindings) */
 
     /* Commands to set default behavior. */
@@ -873,17 +877,7 @@ command (int interactive, char *data)
 
   PRINT_DEBUG ("cmd==%s rest==%s\n", cmd, (char*)rest);
 
-  /* find the command */
-  for (uc = user_commands; uc->name; uc++)
-    {
-      if (!strcmp (cmd, uc->name))
-	{
-	  result = uc->func (interactive, rest);
-	  goto done;
-	}
-    }
-
-  /* Look for it in the aliases. */
+  /* Look for it in the aliases, first. */
   for (i=0; i<alias_list_last; i++)
     {
       if (!strcmp (cmd, alias_list[i].name))
@@ -908,6 +902,16 @@ command (int interactive, char *data)
 	}
     }
 
+  /* If it wasn't an alias, maybe its a command. */
+  for (uc = user_commands; uc->name; uc++)
+    {
+      if (!strcmp (cmd, uc->name))
+	{
+	  result = uc->func (interactive, rest);
+	  goto done;
+	}
+    }
+
   marked_message_printf (0, 0, MESSAGE_UNKNOWN_COMMAND, cmd);
 
  done:
@@ -1467,7 +1471,8 @@ cmd_help (int interactive, void *data)
 	}
 
       y += FONT_HEIGHT (defaults.font);
-      if (y > s->root_attr.height)
+      /* Make sure the next line fits entirely within the window. */
+      if (y + FONT_HEIGHT (defaults.font) >= s->root_attr.height)
 	{
 	  if (drawing_keys)
 	    {
@@ -1479,6 +1484,7 @@ cmd_help (int interactive, void *data)
 	    {
 	      x += max_width + 20;
 	      drawing_keys = 1;
+	      i++;
 	      old_i = i;
 	    }
 
@@ -2072,7 +2078,7 @@ cmd_defbgcolor (int interactive, void *data)
   return NULL;
 }
 
-#ifndef HAVE_SETENV
+#if !defined(HAVE_SETENV) || !defined(setenv)
 /* For systems, such as Solaris, where setenv is not implemented
  * in libc */
 /* FIXME: overwrite has no effect in this implementation! */
@@ -2430,3 +2436,90 @@ cmd_alias (int interactive, void *data)
 
   return NULL;
 }
+
+char *
+cmd_unalias (int interactive, void *data)
+{
+  char *name;
+  int index;
+  
+  if (data == NULL)
+    {
+      message (" unalias: One argument required ");
+      return NULL;
+    }
+
+  /* Parse out the arguments. */
+  name = (char *)data;
+
+  /* Are we updating an existing alias, or creating a new one? */
+  index = find_alias_index (name);
+  if (index >= 0)
+    {
+      char *tmp;
+
+      alias_list_last--;
+
+      /* Free the alias and put the last alias in the the space to
+	 keep alias_list from becoming sparse. This code must jump
+	 through some hoops to correctly handle the case when
+	 alias_list_last == index. */
+      tmp = alias_list[index].alias;
+      alias_list[index].alias = xstrdup (alias_list[alias_list_last].alias);
+      free (tmp);
+      free (alias_list[alias_list_last].alias);
+
+      /* Do the same for the name element. */
+      tmp = alias_list[index].name;
+      alias_list[index].name = xstrdup (alias_list[alias_list_last].name);
+      free (tmp);
+      free (alias_list[alias_list_last].name);
+    }
+  else
+    {
+      message (" unalias: alias not found ");
+    }
+
+  return NULL;  
+}
+
+char *
+cmd_nextscreen (int interactive, void *data)
+{
+  int new_screen;
+
+  /* No need to go through the motions when we don't have to. */
+  if (num_screens <= 1)
+    {
+      message (" nextscreen: No other screen ");
+      return NULL;
+    }
+  new_screen = rp_current_screen + 1;
+  if (new_screen >= num_screens)
+    new_screen = 0;
+
+  set_active_frame (screens[new_screen].rp_current_frame);
+
+  return NULL;
+}
+
+char *
+cmd_prevscreen (int interactive, void *data)
+{
+  int new_screen;
+
+  /* No need to go through the motions when we don't have to. */
+  if (num_screens <= 1) 
+    {
+      message (" prevscreen: No other screen ");
+      return NULL;
+    }
+
+  new_screen = rp_current_screen - 1;
+  if (new_screen < 0)
+    new_screen = num_screens - 1;
+
+  set_active_frame (screens[new_screen].rp_current_frame);
+
+  return NULL;
+}
